@@ -1,3 +1,4 @@
+require 'webrobots/version'
 require 'webrobots/robotstxt'
 require 'uri'
 require 'net/https'
@@ -17,13 +18,34 @@ class WebRobots
   #   the response body if successful, return an empty string if the
   #   resource is not found, and return nil or raise any error on
   #   failure.  Redirects should be handled within this proc.
+  #
+  # * :crawl_delay => determines how to react to Crawl-delay
+  #   directives.  If +:sleep+ is given, WebRobots sleeps as demanded
+  #   when allowed?(url)/disallowed?(url) is called.  This is the
+  #   default behavior.  If +:ignore+ is given, WebRobots does
+  #   nothing.  If a custom method, proc, or anything that responds to
+  #   .call(delay, last_checked_at), it is called.
   def initialize(user_agent, options = nil)
     @user_agent = user_agent
-    @parser = RobotsTxt::Parser.new(user_agent)
-    @parser_mutex = Mutex.new
 
     options ||= {}
     @http_get = options[:http_get] || method(:http_get)
+    crawl_delay_handler =
+      case value = options[:crawl_delay] || :sleep
+      when :ignore
+        nil
+      when :sleep
+        method(:crawl_delay_handler)
+      else
+        if value.respond_to?(:call)
+          value
+        else
+          raise ArgumentError, "invalid Crawl-delay handler: #{value.inspect}"
+        end
+      end
+
+    @parser = RobotsTxt::Parser.new(user_agent, crawl_delay_handler)
+    @parser_mutex = Mutex.new
 
     @robotstxt = create_cache()
   end
@@ -57,6 +79,13 @@ class WebRobots
     !allowed?(url)
   end
 
+  # Returns the number of seconds that the configured agent should wait
+  # between successive requests to the site identified by +url+ according
+  # to the site's robots.txt +Crawl-delay+ directive.
+  def crawl_delay(url)
+    robots_txt_for(url).crawl_delay()
+  end
+
   # Returns extended option values for a resource at +url+ in a hash
   # with each field name lower-cased.  See allowed?() for a list of
   # errors that may be raised.
@@ -169,4 +198,11 @@ class WebRobots
     }
     raise 'too many HTTP redirects'
   end
+
+  def crawl_delay_handler(delay, last_checked_at)
+    if last_checked_at
+      delay -= Time.now - last_checked_at
+      sleep delay if delay > 0
+    end
+  end
 end
